AccessibilityHelper class

Constructors

AccessibilityHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAdaptiveIconSize(BuildContext context, {double normalSize = 24.0, double largeSize = 32.0}) double
getAppBarIconSize(BuildContext context) double
getBottomNavIconSize(BuildContext context) double
getTextScaleFactor(BuildContext context) double
shouldHideLabels(BuildContext context) bool
shouldSplitLayout(BuildContext context) bool