DefaultValues class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apiDataLimit → const int
- debounceDuration → const int
- designButtonHeight → const double
- Button height on the Figma login/full-page screens (mobile density).
- endScrollBuffer → const int
- fileMaxSize → const int
- imageMaxWidth → const int
- maxFtpUsernameLength → const int
- minFtpUsernameLength → const int
- p2 → const double
- p4 → const double
- p8 → const double
- p10 → const double
- p12 → const double
- p16 → const double
- p20 → const double
- p24 → const double
- p32 → const double
- p48 → const double
- p64 → const double
- p180 → const double
- p200 → const double
- p230 → const double
- p250 → const double
- p260 → const double