Utils class
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToDateTime(
String strTime) → DateTime? -
convertUtcDateTimeToReadable(
String datetime) → String -
formatBytes(
num? bytes, [int decimals = 2]) → String -
getFormatedDateWithSlash(
String? datetime) → String -
hideKeyboard(
) → void