NTBDesignColors class abstract final

Chart colors - Figma NTB Design System v3 - collection 2. Theme - mode NTB (colors/chart-*-light / -dark; NTB overrides match for both appearances).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chart1 → const Color
chart2 → const Color
chart3 → const Color
chart4 → const Color
chart5 → const Color