NTBDesignColorsDark class abstract final

Semantic dark theme - Figma 2. Theme - mode NTB (colors/*-dark).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const Color
accentForeground → const Color
background → const Color
border → const Color
card → const Color
cardForeground → const Color
controlTileBorderSelected → const Color
Selected border for checkbox / control tiles (Figma Type=Box, dark).
destructive → const Color
destructiveForeground → const Color
foreground → const Color
input → const Color
muted → const Color
mutedForeground → const Color
popover → const Color
popoverForeground → const Color
primary → const Color
primaryForeground → const Color
ring → const Color
ringOffset → const Color
secondary → const Color
secondaryForeground → const Color
selection → const Color
sidebarAccent → const Color
sidebarAccentForeground → const Color
sidebarBorder → const Color
sidebarForeground → const Color
sidebarPrimary → const Color
sidebarPrimaryForeground → const Color
sidebarRing → const Color
warning → const Color
warningForeground → const Color