Semantic light theme - Figma 2. Theme - mode NTB (colors/*-light).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accent → const Color
- accentForeground → const Color
- background → const Color
- border → const Color
- card → const Color
- cardForeground → const Color
- controlTileBorderSelected → const Color
-
Selected border for checkbox / control tiles (Figma
Type=Box, light). - destructive → const Color
- destructiveForeground → const Color
- foreground → const Color
- input → const Color
- muted → const Color
- mutedForeground → const Color
- popover → const Color
- popoverForeground → const Color
- primary → const Color
- primaryForeground → const Color
- ring → const Color
- ringOffset → const Color
- secondary → const Color
- secondaryForeground → const Color
- selection → const Color
- warning → const Color
- warningForeground → const Color