NTBDesignTypography class abstract final

Typography scale - Figma 2. Theme - collection 2. Theme - mode NTB

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

baseHeight → const double
baseSize → const double
h1Height → const double
h1Size → const double
h1Spacing → const double
h2Height → const double
h2Size → const double
h2Spacing → const double
h3Height → const double
h3Size → const double
h3Spacing → const double
h4Height → const double
h4Size → const double
h4Spacing → const double
height2xl → const double
height3xl → const double
height4xl → const double
height5xl → const double
height6xl → const double
lgHeight → const double
lgSize → const double
size2xl → const double
size3xl → const double
size4xl → const double
size5xl → const double
size6xl → const double
smHeight → const double
smSize → const double
xlHeight → const double
xlSize → const double
xsHeight → const double
xsSize → const double