NTBTailwindColors class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber50 → const Color
amber100 → const Color
amber200 → const Color
amber300 → const Color
amber400 → const Color
amber500 → const Color
amber600 → const Color
amber700 → const Color
amber800 → const Color
amber900 → const Color
amber950 → const Color
black → const Color
blue50 → const Color
blue100 → const Color
blue200 → const Color
blue300 → const Color
blue400 → const Color
blue500 → const Color
blue600 → const Color
blue700 → const Color
blue800 → const Color
blue900 → const Color
blue950 → const Color
cyan50 → const Color
cyan100 → const Color
cyan200 → const Color
cyan300 → const Color
cyan400 → const Color
cyan500 → const Color
cyan600 → const Color
cyan700 → const Color
cyan800 → const Color
cyan900 → const Color
cyan950 → const Color
emerald50 → const Color
emerald100 → const Color
emerald200 → const Color
emerald300 → const Color
emerald400 → const Color
emerald500 → const Color
emerald600 → const Color
emerald700 → const Color
emerald800 → const Color
emerald900 → const Color
emerald950 → const Color
fuchsia50 → const Color
fuchsia100 → const Color
fuchsia200 → const Color
fuchsia300 → const Color
fuchsia400 → const Color
fuchsia500 → const Color
fuchsia600 → const Color
fuchsia700 → const Color
fuchsia800 → const Color
fuchsia900 → const Color
fuchsia950 → const Color
gray50 → const Color
gray100 → const Color
gray200 → const Color
gray300 → const Color
gray400 → const Color
gray500 → const Color
gray600 → const Color
gray700 → const Color
gray800 → const Color
gray900 → const Color
gray950 → const Color
green50 → const Color
green100 → const Color
green200 → const Color
green300 → const Color
green400 → const Color
green500 → const Color
green600 → const Color
green700 → const Color
green800 → const Color
green900 → const Color
green950 → const Color
indigo50 → const Color
indigo100 → const Color
indigo200 → const Color
indigo300 → const Color
indigo400 → const Color
indigo500 → const Color
indigo600 → const Color
indigo700 → const Color
indigo800 → const Color
indigo900 → const Color
indigo950 → const Color
lime50 → const Color
lime100 → const Color
lime200 → const Color
lime300 → const Color
lime400 → const Color
lime500 → const Color
lime600 → const Color
lime700 → const Color
lime800 → const Color
lime900 → const Color
lime950 → const Color
neutral50 → const Color
neutral100 → const Color
neutral200 → const Color
neutral300 → const Color
neutral400 → const Color
neutral500 → const Color
neutral600 → const Color
neutral700 → const Color
neutral800 → const Color
neutral900 → const Color
neutral950 → const Color
orange50 → const Color
orange100 → const Color
orange200 → const Color
orange300 → const Color
orange400 → const Color
orange500 → const Color
orange600 → const Color
orange700 → const Color
orange800 → const Color
orange900 → const Color
orange950 → const Color
pink50 → const Color
pink100 → const Color
pink200 → const Color
pink300 → const Color
pink400 → const Color
pink500 → const Color
pink600 → const Color
pink700 → const Color
pink800 → const Color
pink900 → const Color
pink950 → const Color
purple50 → const Color
purple100 → const Color
purple200 → const Color
purple300 → const Color
purple400 → const Color
purple500 → const Color
purple600 → const Color
purple700 → const Color
purple800 → const Color
purple900 → const Color
purple950 → const Color
red50 → const Color
red100 → const Color
red200 → const Color
red300 → const Color
red400 → const Color
red500 → const Color
red600 → const Color
red700 → const Color
red800 → const Color
red900 → const Color
red950 → const Color
rose50 → const Color
rose100 → const Color
rose200 → const Color
rose300 → const Color
rose400 → const Color
rose500 → const Color
rose600 → const Color
rose700 → const Color
rose800 → const Color
rose900 → const Color
rose950 → const Color
sky50 → const Color
sky100 → const Color
sky200 → const Color
sky300 → const Color
sky400 → const Color
sky500 → const Color
sky600 → const Color
sky700 → const Color
sky800 → const Color
sky900 → const Color
sky950 → const Color
slate50 → const Color
slate100 → const Color
slate200 → const Color
slate300 → const Color
slate400 → const Color
slate500 → const Color
slate600 → const Color
slate700 → const Color
slate800 → const Color
slate900 → const Color
slate950 → const Color
stone50 → const Color
stone100 → const Color
stone200 → const Color
stone300 → const Color
stone400 → const Color
stone500 → const Color
stone600 → const Color
stone700 → const Color
stone800 → const Color
stone900 → const Color
stone950 → const Color
teal50 → const Color
teal100 → const Color
teal200 → const Color
teal300 → const Color
teal400 → const Color
teal500 → const Color
teal600 → const Color
teal700 → const Color
teal800 → const Color
teal900 → const Color
teal950 → const Color
transparent → const Color
violet50 → const Color
violet100 → const Color
violet200 → const Color
violet300 → const Color
violet400 → const Color
violet500 → const Color
violet600 → const Color
violet700 → const Color
violet800 → const Color
violet900 → const Color
violet950 → const Color
white → const Color
yellow50 → const Color
yellow100 → const Color
yellow200 → const Color
yellow300 → const Color
yellow400 → const Color
yellow500 → const Color
yellow600 → const Color
yellow700 → const Color
yellow800 → const Color
yellow900 → const Color
yellow950 → const Color
zinc50 → const Color
zinc100 → const Color
zinc200 → const Color
zinc300 → const Color
zinc400 → const Color
zinc500 → const Color
zinc600 → const Color
zinc700 → const Color
zinc800 → const Color
zinc900 → const Color
zinc950 → const Color