NTBTextThemeVariant enum

Keys for every ShadTextTheme preset plus NTB NTBThemeCustom typography entries.

Inheritance
Available extensions

Values

h1 → const NTBTextThemeVariant
h2 → const NTBTextThemeVariant
h3 → const NTBTextThemeVariant
h4 → const NTBTextThemeVariant
p → const NTBTextThemeVariant
lead → const NTBTextThemeVariant
large → const NTBTextThemeVariant
small → const NTBTextThemeVariant
muted → const NTBTextThemeVariant
button → const NTBTextThemeVariant
input → const NTBTextThemeVariant
cardHeading → const NTBTextThemeVariant
cardDescription → const NTBTextThemeVariant

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NTBTextThemeVariant>
A constant List of the values in this enum, in order of their declaration.