Type-safe keys for custom theme variables.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accentDarkCalendar50 → const String
- accentDarkInput50 → const String
- alpha5 → const String
- alpha10 → const String
- alpha20 → const String
- alpha30 → const String
- alpha30DarkAlpha20 → const String
- alpha40 → const String
- alpha50 → const String
- alpha60 → const String
- alpha70 → const String
- alpha80 → const String
- alpha90 → const String
- amber50DarkAmber950 → const String
- amber200DarkAmber900 → const String
- amber900DarkAmber50 → const String
- backgroundBrand → const String
- backgroundDarkCalendar30 → const String
- backgroundDarkInput30 → const String
- bgBackground20DarkBgBackground10 → const String
- bgPrimary5DarkBgPrimary10 → const String
- blue500DarkBlue600 → const String
- borderDarkInputDark → const String
- cardDescription → const String
- cardHeading → const String
- chart1 → const String
- chart2 → const String
- chart3 → const String
- chart4 → const String
- chart5 → const String
- controlTileBorderSelected → const String
- darkInput → const String
- destructive10DarkDestructive20 → const String
- destructive20DarkDestructive30 → const String
- destructive20DarkDestructive40 → const String
- destructive40DarkDestructive40 → const String
- destructive40DarkDestructive60 → const String
- destructiveBackground → const String
- destructiveBackgroundForeground → const String
- destructiveDarkDestructive60 → const String
- destructiveDarkDestructive70 → const String
- destructiveDarkDestructive90 → const String
- foregroundBrand → const String
- input → const String
- input30DarkInput30 → const String
- input30DarkTransparent → const String
- input50DarkInput80 → const String
- inputDarkInput80 → const String
- mutedDarkInput50 → const String
- neutral800DarkNeutral300 → const String
- online → const String
- outline → const String
- outline10DarkOutline20 → const String
- ringDarkInputDark → const String
- ringDarkInputDark2 → const String
- ringOffset → const String
- success → const String
- successForeground → const String
- warning → const String
- warning10DarkWarning20 → const String
- warning20DarkWarning30 → const String
- warning20DarkWarning40 → const String
- warning40DarkWarning40 → const String
- warning40DarkWarning60 → const String
- warningDarkWarning60 → const String
- warningDarkWarning70 → const String
- warningDarkWarning90 → const String
- warningForeground → const String