NTBTokens class

Constructors

NTBTokens()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

primaryPressedLight Color
getter/setter pair

Static Methods

primaryHover(Brightness brightness) Color
primaryPressed(Brightness brightness) Color

Constants

primaryHoverDark → const Color
primaryHoverLight → const Color
primaryPressedDark → const Color