ShadColorScheme class
- Available extensions
- Annotations
Constructors
-
ShadColorScheme({bool canMerge = true, required Color background, required Color foreground, required Color card, required Color cardForeground, required Color popover, required Color popoverForeground, required Color primary, required Color primaryForeground, required Color secondary, required Color secondaryForeground, required Color muted, required Color mutedForeground, required Color accent, required Color accentForeground, required Color destructive, required Color destructiveForeground, required Color border, required Color input, required Color ring, required Color selection, Map<
String, Color> custom = const {}}) -
const
- ShadColorScheme.fromName(String name, {Brightness brightness = Brightness.light})
-
factory
Properties
- accent → Color
-
final
- accentDarkCalendar50 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - accentDarkInput50 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - accentForeground → Color
-
final
- alpha10 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha20 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha30DarkAlpha20 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha40 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha5 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha50 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha60 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha70 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha80 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - alpha90 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - amber200DarkAmber900 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - amber50DarkAmber950 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - amber900DarkAmber50 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - background → Color
-
final
- backgroundBrand → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - backgroundDarkCalendar30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - backgroundDarkInput30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - bgBackground20DarkBgBackground10 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - bgPrimary5DarkBgPrimary10 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - blue500DarkBlue600 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - border → Color
-
final
- borderDarkInputDark → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - canMerge → bool
-
no setter
- card → Color
-
final
- cardForeground → Color
-
final
- chart1 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - chart2 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - chart3 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - chart4 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - chart5 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - controlTileBorderSelected → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
custom
→ Map<
String, Color> -
final
- darkInput → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructive → Color
-
final
- destructive10DarkDestructive20 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructive20DarkDestructive30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructive20DarkDestructive40 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructive40DarkDestructive40 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructive40DarkDestructive60 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveBackground → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveBackgroundForeground → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveDarkDestructive60 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveDarkDestructive70 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveDarkDestructive90 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - destructiveForeground → Color
-
final
- foreground → Color
-
final
- foregroundBrand → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- input → Color
-
final
- input30DarkInput30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - input30DarkTransparent → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - input50DarkInput80 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - inputDarkInput80 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - muted → Color
-
final
- mutedDarkInput50 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - mutedForeground → Color
-
final
- neutral800DarkNeutral300 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - online → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - outline → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - outline10DarkOutline20 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - popover → Color
-
final
- popoverForeground → Color
-
final
- primary → Color
-
final
- primaryForeground → Color
-
final
- ring → Color
-
final
- ringDarkInputDark → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - ringDarkInputDark2 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - ringOffset → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
final
- secondaryForeground → Color
-
final
- selection → Color
-
final
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter -
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - success → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - successForeground → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning10DarkWarning20 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning20DarkWarning30 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning20DarkWarning40 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning40DarkWarning40 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warning40DarkWarning60 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warningDarkWarning60 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warningDarkWarning70 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warningDarkWarning90 → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter - warningForeground → Color
-
Available on ShadColorScheme, provided by the NTBColorSchemeX extension
no setter
Methods
-
copyWith(
{Color? background, Color? foreground, Color? card, Color? cardForeground, Color? popover, Color? popoverForeground, Color? primary, Color? primaryForeground, Color? secondary, Color? secondaryForeground, Color? muted, Color? mutedForeground, Color? accent, Color? accentForeground, Color? destructive, Color? destructiveForeground, Color? border, Color? input, Color? ring, Color? selection, Map< String, Color> ? custom}) → ShadColorScheme - Creates a copy of this ShadColorScheme but with the given fields replaced with the new values.
-
merge(
ShadColorScheme? other) → ShadColorScheme -
Merges this ShadColorScheme with
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
ShadColorScheme a, ShadColorScheme b, double t) → ShadColorScheme